@@ -7,7 +7,7 @@ import threading
 
 import requests
 
-__version__ = '1.4.6b'
+__version__ = '1.5.1b'
 
 class Event(object):
 	def __init__(self, connection):
@@ -113,21 +113,21 @@ class Event(object):
 		else:
 			return False
 
-class PrivateMessage(ChatBot):
-	def __init__(self, username, password):
-		ChatBot.__init__(self)
-		self.c = Client(username, password, wiki)
-		self.changed = False
-		self.message = ""
-
-	def send(self, message):
-		self.changed = True
-		self.message = message
-
-	def on_message(self, c, e):
-		if self.changed:
-			c.send(c, message)
-			self.changed = False
+#class PrivateMessage(ChatBot):
+#	def __init__(self, username, password):
+#		ChatBot.__init__(self)
+#		self.c = Client(username, password, wiki)
+#		self.changed = False
+#		self.message = ""
+#
+#	def send(self, message):
+#		self.changed = True
+#		self.message = message
+#
+#	def on_message(self, c, e):
+#		if self.changed:
+#			c.send(c, message)
+#			self.changed = False
 
 
 
